import json


def _prepare_json_fragment(ifg, filename, x_before_transform, y_before_transform, verbosity=0):
    if hasattr(ifg, "phase") and ifg.phase is not None:
        phase_or_GD = ifg.phase
    elif hasattr(ifg, "GD") and ifg.GD is not None:
        phase_or_GD = ifg.GD
    else:
        phase_or_GD = False
    if verbosity > 0:
        return {
            filename: {
                "method": str(ifg.__class__).split(".")[-1].strip("''>"),
                "GD": getattr(phase_or_GD, "GD", 0),
                "GDD": getattr(phase_or_GD, "GDD", 0),
                "TOD": getattr(phase_or_GD, "TOD", 0),
                "FOD": getattr(phase_or_GD, "FOD", 0),
                "QOD": getattr(phase_or_GD, "QOD", 0),
                "SOD": getattr(phase_or_GD, "SOD", 0),
                "meta": {} if len(ifg.meta) == 0 else ifg.meta,
                "x": x_before_transform.tolist(),
                "y": y_before_transform.tolist(),
                "phase": {
                    "is_GD": getattr(phase_or_GD, "GD_mode", False),
                    "x": list(getattr(phase_or_GD, "x", [])),
                    "y": list(getattr(phase_or_GD, "y", [])),
                },
            }
        }
    else:
        return {
            filename: {
                "method": str(ifg.__class__).split(".")[-1].strip("''>"),
                "GD": getattr(phase_or_GD, "GD", 0),
                "GDD": getattr(phase_or_GD, "GDD", 0),
                "TOD": getattr(phase_or_GD, "TOD", 0),
                "FOD": getattr(phase_or_GD, "FOD", 0),
                "QOD": getattr(phase_or_GD, "QOD", 0),
                "SOD": getattr(phase_or_GD, "SOD", 0),
                "meta": {} if len(ifg.meta) == 0 else ifg.meta,
            }
        }


def _write_or_update_json_fragment(filename, new_ifg, new_ifg_name):
    # open in read mode, check what operation to run
    with open(filename, "r") as json_file:
        data = json.load(json_file)

    data[new_ifg_name] = new_ifg[new_ifg_name]

    # reopen in write mode (the cursor is at the end of the file
    # after read, it's just easier to reopen)
    with open(filename, "w") as json_file:
        json_file.write(json.dumps(data, indent=2))



import os
import platform
import pytest

no_osx = pytest.mark.skipif(platform.system() == 'Darwin', reason="There is no xvfb on osx.")
no_mpl = pytest.mark.skipif(os.environ.get("RUNNER_OS", None) == "Linux", reason="There is no xvfb setup on Linux")



from .misc import *
from .meta import *
from ._spp_helpers import *
from .exceptions import *
from ._evalutils import *
from .info import *
from .decorators import *
from .serializer import _write_or_update_json_fragment, _prepare_json_fragment



import sys
import versioneer


if sys.version_info[:2] < (3, 6):
    raise RuntimeError("Python version >= 3.6 required.")


from setuptools import setup, find_packages


with open("README.md", "r") as fh:
    long_description = fh.read()

try:
    from setuptools_rust import RustExtension, Binding
except ImportError:
    import subprocess

    errno = subprocess.call([sys.executable, "-m", "pip", "install", "setuptools-rust"])
    if errno:
        print("Please install setuptools-rust package")
        raise SystemExit(errno)
    else:
        from setuptools_rust import RustExtension, Binding

setup(
    name="pysprint",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    author="Péter Leéh",
    author_email="leeh123peter@gmail.com",
    description="Spectrally refined interferometry for Python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Ptrskay3/PySprint",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Rust",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Physics",
    ],
    install_requires=[
        "numpy>=1.16.6",
        "scipy",
        "matplotlib",
        "pandas",
        "Jinja2",
        "scikit-learn",
    ],
    setup_requires=["setuptools-rust>=0.11.4", "wheel"],
    extras_require={"optional": ["numba", "lmfit", "pytest", "dask"]},
    rust_extensions=[
        RustExtension(
            "pysprint.internals",
            "Cargo.toml",
            debug=False,
            binding=Binding.PyO3,
            # py_limited_api=True,
            # features=["pyo3/abi3"],
        ),
    ],
    entry_points={
        "console_scripts": [
            "pysprint = pysprint.templates.build:main",
        ],
    },
    zip_safe=False,
)
